package
Version:
v0.8.3
Opens a new window with list of versions in this module.
Published: Aug 21, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type HealthConfiguration struct {
Addr string `yaml:"addr" default:":8888" help:"health server address"`
Path string `yaml:"path" default:"/healthz" help:"health server path"`
}
type LogConfiguration struct {
Format string `yaml:"format" default:"json" help:"log format. Valid values are json and text"`
Level string `yaml:"level" default:"info" help:"log level. Valid values are debug, info, warn, error"`
}
type PrometheusConfiguration struct {
Addr string `yaml:"addr" default:":9100" help:"prometheus server address"`
Path string `yaml:"path" default:"/metrics" help:"prometheus server path"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.